Package: shinyds
Title: 'Shiny' Bindings for Designsystemet Components
Version: 0.5.0
Authors@R: c(
    person("Novica", "Nakov", , "nnovica@gmail.com", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0009-0005-7773-7718")))
Description: Provides 'R' wrappers for the Designsystemet component library
    <https://designsystemet.no>, enabling use of Norwegian government design system
    components in 'Shiny' applications. Includes web components and CSS-based
    HTML components with full 'Shiny' input binding support.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 8.0.0
Imports: htmltools (>= 0.5.0), shiny (>= 1.7.0)
Suggests: testthat (>= 3.0.0), shinytest2, chromote, jsonlite, withr,
        bslib, quarto
VignetteBuilder: quarto
Config/testthat/edition: 3
Config/roxygen2/markdown: TRUE
Config/roxygen2/version: 8.0.0
URL: https://github.com/novica/shinyds
BugReports: https://github.com/novica/shinyds/issues
NeedsCompilation: no
Packaged: 2026-08-22 11:22:03 UTC; novica
Author: Novica Nakov [aut, cre, cph] (ORCID:
    <https://orcid.org/0009-0005-7773-7718>)
Maintainer: Novica Nakov <nnovica@gmail.com>
Repository: CRAN
Date/Publication: 2026-08-22 11:40:02 UTC
Built: R 4.5.2; ; 2026-08-22 14:55:56 UTC; unix
